@@ -6,6 +6,7 @@ class Metrics(object):
     def __init__(self, trexclient):
         self._client = trexclient
 
+
     def get_metrics(self, request, port_ids, capture):
         req = json.loads(request.serialize())
         mc = Util.get_metrics_columns()
@@ -16,7 +17,7 @@ class Metrics(object):
             for p_name in req['port']['port_names']:
                 ports.append(port_ids.index(p_name))
 
-        col_names = ['transmit', 'location', 'link', 'capture', 'frames_tx', 'frames_rx',
+        col_names = ['location', 'link', 'capture', 'frames_tx', 'frames_rx',
                     'bytes_tx', 'bytes_rx', 'frames_tx_rate', 'frames_rx_rate', 
                     'bytes_tx_rate', 'bytes_rx_rate']
         if req['port']['column_names'] is not None:
