@@ -183,6 +183,7 @@ class Api(snappi.Api):
 
 
     def set_link_state(self, payload):
+        Validation.validate_link(payload, self._port_ids)
         ls = json.loads(payload.serialize())
         ports = list(range(len(self._port_ids)))
         if ls['port_names'] is not None:
@@ -226,6 +227,7 @@ class Api(snappi.Api):
           #/components/schemas/Result.MetricsRequest
           See the docs/openapi.yaml document for all model details
         """
+        Validation.validate_metrics_request(request, self._port_ids)
         return self._metrics.get_metrics(request, self._port_ids, self._capture)
 
 
